@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11945 2020-02-21 11:10:48Z Lavender $
+# $Id: admin.py 11953 2020-02-25 08:39:42Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-02-21 19:10:48 +0800 (週五, 21 二月 2020) $
-# $Revision: 11945 $
+# $Date: 2020-02-25 17:39:42 +0900 (週二, 25 二月 2020) $
+# $Revision: 11953 $
 
 import os
 import datetime
@@ -33,6 +33,7 @@ from django.db import transaction
 from django.conf.urls import url
 from django.http import HttpResponseRedirect
 from django.contrib import messages
+from django.template.loader import engines
 
 from Iuppiter.DjangoUtil import DJANGO_VERSION, reverse
 
@@ -382,6 +383,11 @@ class BaseFileAdmin(admin.ModelAdmin):
             logger.info("File has modified: %s" % obj.path)
             version = createVersion(self.model, obj)
 
+        # reload loader
+        for engine in engines.all():
+            for loader in engine.engine.template_loaders:
+                loader.reset()
+
         return super(BaseFileAdmin, self).response_change(request, obj)
 
     def changelist_view(self, request, extra_context=None):
